@@ -6,7 +6,7 @@
 # http://www.popbill.com
 # Author : Jeong Yohan (code@linkhub.co.kr)
 # Written : 2015-03-24
-# Updated : 2019-10-24
+# Updated : 2021-04-21
 # Thanks for your interest.
 
 from .base import PopbillBase, PopbillException
@@ -70,17 +70,17 @@ class CashbillService(PopbillBase):
         return float(result.unitCost)
 
     def checkMgtKeyInUse(self, CorpNum, MgtKey):
-        """ 파트너 문서관리번호 사용여부 확인.
+        """ 파트너 문서번호 사용여부 확인.
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호(최대 24자리, 숫자, 영문,'-','_'로 구성)
+                MgtKey : 문서번호(최대 24자리, 숫자, 영문,'-','_'로 구성)
             return
                 사용 여부 by True/False
             raise
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         try:
             result = self._httpget('/Cashbill/' + MgtKey, CorpNum)
@@ -142,7 +142,7 @@ class CashbillService(PopbillBase):
         """ 취소현금영수증 즉시발행
             args
                 CorpNum : 팝빌회원 사업자번호
-                mgtKey : 현금영수증 문서관리번호
+                mgtKey : 현금영수증 문서번호
                 orgConfirmNum : 원본현금영수증 승인번호
                 orgTradeDate : 원본현금영수증 거래일자
                 smssendYN : 발행안내문자 전송여부
@@ -182,7 +182,7 @@ class CashbillService(PopbillBase):
         """ 취소현금영수증 임시저장
             args
                 CorpNum : 팝빌회원 사업자번호
-                mgtKey : 현금영수증 문서관리번호
+                mgtKey : 현금영수증 문서번호
                 orgConfirmNum : 원본현금영수증 승인번호
                 orgTradeDate : 원본현금영수증 거래일자
                 smssendYN : 발행안내문자 전송여부
@@ -218,7 +218,7 @@ class CashbillService(PopbillBase):
         """ 수정
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 원본 현금영수증 문서관리번호
+                MgtKey : 원본 현금영수증 문서번호
                 cashbill : 수정할 현금영수증 object. made with Cashbill(...)
                 UserID : 팝빌회원 아이디
             return
@@ -227,7 +227,7 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
         if cashbill == None:
             raise PopbillException(-99999999, "현금영수증 정보가 입력되지 않았습니다.")
 
@@ -239,7 +239,7 @@ class CashbillService(PopbillBase):
         """ 발행
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 원본 현금영수증 문서관리번호
+                MgtKey : 원본 현금영수증 문서번호
                 Memo : 발행 메모
                 UserID : 팝빌회원 아이디
             return
@@ -249,7 +249,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         postData = ""
         req = {}
@@ -265,7 +265,7 @@ class CashbillService(PopbillBase):
         """ 발행취소
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 원본 현금영수증 문서관리번호
+                MgtKey : 원본 현금영수증 문서번호
                 Memo : 발행취소 메모
                 UserID : 팝빌회원 아이디
             return
@@ -275,7 +275,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         postData = ""
         req = {}
@@ -291,7 +291,7 @@ class CashbillService(PopbillBase):
         """ 삭제
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 원본 현금영수증 문서관리번호
+                MgtKey : 원본 현금영수증 문서번호
                 UserID : 팝빌회원 아이디
             return
                 처리결과. consist of code and message
@@ -300,7 +300,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         return self._httppost('/Cashbill/' + MgtKey, '', CorpNum, UserID, "DELETE")
 
@@ -357,7 +357,7 @@ class CashbillService(PopbillBase):
         """ 상태/요약 정보 조회
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
             return
                 문서 상태/요약 정보 object
             raise
@@ -365,7 +365,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         return self._httpget('/Cashbill/' + MgtKey, CorpNum)
 
@@ -373,14 +373,14 @@ class CashbillService(PopbillBase):
         """ 상태정보 다량 확인, 최대 1000건
             args
                 CorpNum : 회원 사업자 번호
-                MgtKeyList : 문서관리번호 목록
+                MgtKeyList : 문서번호 목록
             return
                 상태정보 목록 as List
             raise
                 PopbillException
         """
         if MgtKeyList == None or len(MgtKeyList) < 1:
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         postData = self._stringtify(MgtKeyList)
 
@@ -390,7 +390,7 @@ class CashbillService(PopbillBase):
         """ 상세정보 조회
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
             return
                 문서 상세정보 object
             raise
@@ -398,7 +398,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         return self._httpget('/Cashbill/' + MgtKey + '?Detail', CorpNum)
 
@@ -406,7 +406,7 @@ class CashbillService(PopbillBase):
         """ 알림메일 재전송
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 ReceiverEmail : 수신자 이메일 주소
                 UserID : 팝빌회원 아이디
             return
@@ -416,7 +416,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
         if ReceiverEmail == None or ReceiverEmail == "":
             raise PopbillException(-99999999, "수신자 메일주소가 입력되지 않았습니다.")
 
@@ -428,7 +428,7 @@ class CashbillService(PopbillBase):
         """ 알림문자 전송
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 Sender : 발신번호
                 Receiver : 수신번호
                 Contents : 문자 메시지 내용. 최대 90Byte. 초과시 길이가 조정되어 전송됨
@@ -440,7 +440,7 @@ class CashbillService(PopbillBase):
         """
 
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
         if Receiver == None or Receiver == "":
             raise PopbillException(-99999999, "문자 수신번호가 입력되지 않았습니다.")
 
@@ -456,7 +456,7 @@ class CashbillService(PopbillBase):
         """ 현금영수증 팩스전송
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 Sender : 발신번호
                 Receiver : 수신번호
                 UserID : 팝빌회원 아이디
@@ -466,7 +466,7 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
         if Receiver == None or Receiver == "":
             raise PopbillException(-99999999, "팩스 수신번호가 입력되지 않았습니다.")
 
@@ -481,14 +481,14 @@ class CashbillService(PopbillBase):
         """ 문서이력 조회
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
             return
                 문서 이력 목록 as List
             raise
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         return self._httpget('/Cashbill/' + MgtKey + '/Logs', CorpNum)
 
@@ -496,7 +496,7 @@ class CashbillService(PopbillBase):
         """ 현금영수증 1장의 팝빌 화면을 볼수있는 팝업 URL 확인
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 UserID : 팝빌회원 아이디
             return
                 팝빌 URL as str
@@ -504,17 +504,43 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         result = self._httpget('/Cashbill/' + MgtKey + '?TG=POPUP', CorpNum, UserID)
 
         return result.url
 
+    def getViewURL(self, CorpNum, MgtKey, UserID=None):
+        """ 현금영수증 1장의 팝빌 화면을 볼수있는 팝업 URL 확인(메뉴/버튼 제외)
+            args
+                CorpNum : 팝빌회원 사업자번호
+                MgtKey : 문서번호
+                UserID : 팝빌회원 아이디
+            return
+                팝빌 URL as str
+            raise
+                PopbillException
+        """
+        if MgtKey == None or MgtKey == "":
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
+
+        result = self._httpget('/Cashbill/' + MgtKey + '?TG=VIEW', CorpNum, UserID)
+
+        return result.url
+
+    def getPDFURL(self, CorpNum, MgtKey, UserID=None):
+        if MgtKey == None or MgtKey == "":
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
+
+        result = self._httpget('/Cashbill/' + MgtKey + '?TG=PDF', CorpNum, UserID)
+
+        return result.url
+
     def getPrintURL(self, CorpNum, MgtKey, UserID=None):
         """ 공급자용 인쇄 URL 확인
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 UserID : 팝빌회원 아이디
             return
                 팝빌 URL as str
@@ -522,7 +548,7 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         result = self._httpget('/Cashbill/' + MgtKey + '?TG=PRINT', CorpNum, UserID)
 
@@ -532,7 +558,7 @@ class CashbillService(PopbillBase):
         """ 공급받는자용 인쇄 URL 확인
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 UserID : 팝빌회원 아이디
             return
                 팝빌 URL as str
@@ -540,7 +566,7 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         result = self._httpget('/Cashbill/' + MgtKey + '?TG=EPRINT', CorpNum, UserID)
 
@@ -550,7 +576,7 @@ class CashbillService(PopbillBase):
         """ 공급받는자용 메일 링크 URL 확인
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKey : 문서관리번호
+                MgtKey : 문서번호
                 UserID : 팝빌회원 아이디
             return
                 팝빌 URL as str
@@ -558,7 +584,7 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKey == None or MgtKey == "":
-            raise PopbillException(-99999999, "관리번호가 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
         result = self._httpget('/Cashbill/' + MgtKey + '?TG=MAIL', CorpNum, UserID)
 
@@ -568,7 +594,7 @@ class CashbillService(PopbillBase):
         """ 다량 인쇄 URL 확인
             args
                 CorpNum : 팝빌회원 사업자번호
-                MgtKeyList : 문서관리번호 배열
+                MgtKeyList : 문서번호 배열
                 UserID : 팝빌회원 아이디
             return
                 팝빌 URL as str
@@ -576,7 +602,7 @@ class CashbillService(PopbillBase):
                 PopbillException
         """
         if MgtKeyList == None:
-            raise PopbillException(-99999999, "관리번호 배열이 입력되지 않았습니다.")
+            raise PopbillException(-99999999, "문서번호 배열이 입력되지 않았습니다.")
 
         postData = self._stringtify(MgtKeyList)
 
@@ -617,6 +643,18 @@ class CashbillService(PopbillBase):
         uri = "/Cashbill/EmailSendConfig?EmailType=" + EmailType + "&SendYN=" + str(SendYN)
         return self._httppost(uri, "", Corpnum, UserID)
 
+    def assignMgtKey(self, CorpNum, ItemKey, MgtKey, UserID=None):
+
+        if ItemKey == None or ItemKey == '':
+            raise PopbillException(-99999999, "아이템키가 입력되지 않았습니다.")
+
+        if MgtKey == None or MgtKey == '':
+            raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
+
+        postDate = "MgtKey=" + MgtKey
+        return self._httppost('/Cashbill/' + ItemKey, postDate, CorpNum, UserID, "",
+                              "application/x-www-form-urlencoded; charset=utf-8")
+
 
 class Cashbill(object):
     def __init__(self, **kwargs):
