@@ -7,7 +7,7 @@
 # Author : Kim Seongjun (pallet027@gmail.com)
 # Written : 2015-01-21
 # Contributor : Jeong Yohan (code@linkhub.co.kr)
-# Updated : 2018-08-09
+# Updated : 2021-04-22
 # Thanks for your interest.
 from datetime import datetime
 from .base import PopbillBase, PopbillException, File
@@ -305,6 +305,109 @@ class FaxService(PopbillBase):
 
         return result.receiptNum
 
+    def sendFaxBinary(self, CorpNum, SenderNum, ReceiverNum, ReceiverName, FileDatas, ReserveDT=None, UserID=None,
+                SenderName=None, adsYN=False, title=None, RequestNum=None):
+        """ 바이너리 데이터 팩스 단건 전송
+            args
+                CorpNum : 팝빌회원 사업자번호
+                SenderNum : 발신자 번호
+                ReceiverNum : 수신자 번호
+                ReceiverName : 수신자 이름
+                FileDatas : 발신 파일 정보
+                ReserveDT : 예약시간(형식 yyyyMMddHHmmss)
+                UserID : 팝빌회원 아이디
+                SenderName : 발신자명 (동보전송용)
+                adsYN : 광고팩스 여부
+                title : 팩스제목
+                RequestNum : 전송요청시 할당한 전송요청번호
+            return
+                접수번호 (receiptNum)
+            raise
+                PopbillException
+        """
+
+        receivers = []
+        receivers.append(FaxReceiver(receiveNum=ReceiverNum,
+                                     receiveName=ReceiverName)
+                         )
+
+        return self.sendFaxBinary_multi(CorpNum, SenderNum, receivers, FileDatas, ReserveDT, UserID, SenderName, adsYN, title,
+                                  RequestNum)
+
+    def sendFaxBinary_multi(self, CorpNum, SenderNum, Receiver, FileDatas, ReserveDT=None, UserID=None,
+                SenderName=None, adsYN=False, title=None, RequestNum=None):
+        """ 바이너리 데이터 팩스 다건 전송
+            args
+                CorpNum : 팝빌회원 사업자번호
+                SenderNum : 발신자 번호 (동보전송용)
+                Receiver : 수신자 정보(동보전송용)
+                FileDatas : 발신 파일 정보
+                ReserveDT : 예약시간(형식 yyyyMMddHHmmss)
+                UserID : 팝빌회원 아이디
+                SenderName : 발신자 이름 (동보전송용)
+                adsYN : 광고팩스 여부
+                title : 팩스제목
+                RequestNum : 전송요청시 할당한 전송요청번호
+            return
+                접수번호 (receiptNum)
+            raise
+                PopbillException
+        """
+
+        if SenderNum == None or SenderNum == "":
+            raise PopbillException(-99999999, "발신자 번호가 입력되지 않았습니다.")
+
+        if Receiver == None or Receiver == "":
+            raise PopbillException(-99999999, "수신자 정보가 입력되지 않았습니다.")
+
+        if not (type(Receiver) is str or type(Receiver) is FaxReceiver or type(Receiver) is list):
+            raise PopbillException(-99999999, "'Receiver' argument type error. 'FaxReceiver' or List of 'FaxReceiver'.")
+
+        if FileDatas == None:
+            raise PopbillException(-99999999, "전송 파일 정보가 입력되지 않았습니다.")
+
+        if not type(FileDatas) is list:
+            raise PopbillException(-99999999, "'FileDatas' argument type error. List of FileData")
+
+        if (len(FileDatas) < 1 or len(FileDatas) > 20):
+            raise PopbillException(-99999999, "파일은 1개 이상, 20개 까지 전송 가능합니다.")
+
+        req = {"snd": SenderNum, "sndnm": SenderName, "fCnt": len(FileDatas), "rcvs": [], "sndDT": None}
+
+        if (type(Receiver) is str):
+            Receiver = FaxReceiver(receiveNum=Receiver)
+
+        if (type(Receiver) is FaxReceiver):
+            Receiver = [Receiver]
+
+        if adsYN:
+            req['adsYN'] = True
+
+        for r in Receiver:
+            req['rcvs'].append({"rcv": r.receiveNum, "rcvnm": r.receiveName})
+
+        if ReserveDT != None:
+            req['sndDT'] = ReserveDT
+
+        if title != None:
+            req['title'] = title
+
+        if RequestNum != None:
+            req['requestNum'] = RequestNum
+
+        postData = self._stringtify(req)
+
+        files = []
+        for file in FileDatas:
+            files.append(File(fieldName='file',
+                              fileName=file.fileName,
+                              fileData=file.fileData)
+                        )
+
+        result = self._httppost_files('/FAX', postData, files, CorpNum, UserID)
+
+        return result.receiptNum
+
     def resendFax(self, CorpNum, ReceiptNum, SenderNum, SenderName, ReceiverNum, ReceiverName, ReserveDT=None,
                   UserID=None, title=None, RequestNum=None):
         """ 팩스 단건 전송
@@ -496,3 +599,8 @@ class FaxReceiver(object):
     def __init__(self, **kwargs):
         self.__dict__ = dict.fromkeys(['receiveNum', 'receiveName'])
         self.__dict__.update(kwargs)
+
+class FileData(object):
+    def __init__(self, **kwargs):
+            self.__dict__ = dict.fromkeys(['fileName', 'fileData'])
+            self.__dict__.update(kwargs)
